==> limesuite_17.12.0+dfsg.orig.tar.gz: LimeSuite-17.12.0/src/ConnectionXillybus/ConnectionXillybus.h <==
/**
    @file ConnectionSTREAM.h
    @author Lime Microsystems
    @brief Implementation of STREAM board connection.
*/

#pragma once
#include <ConnectionRegistry.h>
#include <ILimeSDRStreaming.h>
#include <vector>
#include <string>
#include <atomic>
#include <memory>
#include <thread>
#include "fifo.h"

#ifndef __unix__
#include "windows.h"
#else
#include <mutex>
#include <condition_variable>
#include <chrono>
#endif

namespace lime{

class ConnectionXillybus : public ILimeSDRStreaming
{
public:
    ConnectionXillybus(const unsigned index);
    ~ConnectionXillybus(void);

    int Open(const unsigned index);
    void Close();
    bool IsOpen();
    int GetOpenedIndex();

    int Write(const unsigned char *buffer, int length, int timeout_ms = 100) override;
    int Read(unsigned char *buffer, int length, int timeout_ms = 100) override;

    //hooks to update FPGA plls when baseband interface data rate is changed
    int UpdateExternalDataRate(const size_t channel, const double txRate, const double rxRate) override;
    int UpdateExternalDataRate(const size_t channel, const double txRate, const double rxRate, const double txPhase, const double rxPhase)override;
    int ReadRawStreamData(char* buffer, unsigned length, int epIndex, int timeout_ms = 100)override;
#ifdef __unix__
    int TransferPacket(GenericPacket &pkt) override;
    int ProgramWrite(const char *data_src, const size_t length, const int prog_mode, const int device, ProgrammingCallback callback)override;
#endif
protected:
    void ReceivePacketsLoop(Streamer* args) override;
    void TransmitPacketsLoop(Streamer* args) override;

    int ReceiveData(char* buffer, int length, int epIndex, int timeout = 100) override;
    int SendData(const char* buffer, int length, int epIndex, int timeout = 100) override;
    void AbortReading(int epIndex);
    void AbortSending(int epIndex);

private:
    static const int MAX_EP_CNT = 3;
    struct EPConfig
    {
        std::string ctrlRead;
        std::string ctrlWrite;
        std::string streamRead[MAX_EP_CNT];
        std::string streamWrite[MAX_EP_CNT];
    };

    static const EPConfig deviceConfigs[];
    eConnectionType GetType(void)
    {
        return PCIE_PORT;
    }

    std::string m_hardwareName;
    int m_hardwareVer;

    bool isConnected;
    std::mutex mTransferLock;
#ifndef __unix__
    HANDLE hWrite;
    HANDLE hRead;
    HANDLE hWriteStream[MAX_EP_CNT];
    HANDLE hReadStream[MAX_EP_CNT];
#else
    int OpenControl();
    void CloseControl();
    int hWrite;
    int hRead;
    int hWriteStream[MAX_EP_CNT];
    int hReadStream[MAX_EP_CNT];
#endif
    std::string writeCtrlPort;
    std::string readCtrlPort;
    std::string writeStreamPort[MAX_EP_CNT];
    std::string readStreamPort[MAX_EP_CNT];
};



class ConnectionXillybusEntry : public ConnectionRegistryEntry
{
public:
    ConnectionXillybusEntry(void);

    ~ConnectionXillybusEntry(void);

    std::vector<ConnectionHandle> enumerate(const ConnectionHandle &hint);

    IConnection *make(const ConnectionHandle &handle);

private:
    #ifndef __unix__
    std::string DeviceName(unsigned int index);
    #else
    #endif
};

}

==> limesuite_18.06.0+dfsg.orig.tar.gz: LimeSuite-18.06.0/src/ConnectionXillybus/ConnectionXillybus.h <==
/**
    @file ConnectionSTREAM.h
    @author Lime Microsystems
    @brief Implementation of STREAM board connection.
*/

#pragma once
#include <ConnectionRegistry.h>
#include "LMS64CProtocol.h"
#include <vector>
#include <string>
#include <atomic>
#include <memory>
#include <thread>

#ifndef __unix__
#include "windows.h"
#else
#include <mutex>
#include <condition_variable>
#include <chrono>
#endif

namespace lime{

class ConnectionXillybus : public LMS64CProtocol
{
public:
    ConnectionXillybus(const unsigned index);
    ~ConnectionXillybus(void);

    int Open(const unsigned index);
    void Close();
    bool IsOpen();
    int GetOpenedIndex();

    int Write(const unsigned char *buffer, int length, int timeout_ms = 100) override;
    int Read(unsigned char *buffer, int length, int timeout_ms = 100) override;
;
#ifdef __unix__
    int TransferPacket(GenericPacket &pkt) override;
    int ProgramWrite(const char *data_src, const size_t length, const int prog_mode, const int device, ProgrammingCallback callback)override;
#endif
protected:
    int GetBuffersCount() const override;
    int CheckStreamSize(int size) const override;
    
    int ReceiveData(char* buffer, int length, int epIndex, int timeout = 100) override;
    int SendData(const char* buffer, int length, int epIndex, int timeout = 100) override;
    
    int BeginDataReading(char* buffer, uint32_t length, int ep) override;
    bool WaitForReading(int contextHandle, unsigned int timeout_ms) override;
    int FinishDataReading(char* buffer, uint32_t length, int contextHandle) override;
    void AbortReading(int epIndex);

    int BeginDataSending(const char* buffer, uint32_t length, int ep) override;
    bool WaitForSending(int contextHandle, uint32_t timeout_ms) override;
    int FinishDataSending(const char* buffer, uint32_t length, int contextHandle) override;
    void AbortSending(int epIndex);

private:
    static const int MAX_EP_CNT = 3;
    struct EPConfig
    {
        std::string ctrlRead;
        std::string ctrlWrite;
        std::string streamRead[MAX_EP_CNT];
        std::string streamWrite[MAX_EP_CNT];
    };

    static const EPConfig deviceConfigs[];
    eConnectionType GetType(void) {return PCIE_PORT;}

    std::string m_hardwareName;
    int m_hardwareVer;

    bool isConnected;
    std::mutex mTransferLock;
#ifndef __unix__
    HANDLE hWrite;
    HANDLE hRead;
    HANDLE hWriteStream[MAX_EP_CNT];
    HANDLE hReadStream[MAX_EP_CNT];
#else
    int OpenControl();
    void CloseControl();
    int hWrite;
    int hRead;
    int hWriteStream[MAX_EP_CNT];
    int hReadStream[MAX_EP_CNT];
#endif
    std::string writeCtrlPort;
    std::string readCtrlPort;
    std::string writeStreamPort[MAX_EP_CNT];
    std::string readStreamPort[MAX_EP_CNT];
};

class ConnectionXillybusEntry : public ConnectionRegistryEntry
{
public:
    ConnectionXillybusEntry(void);

    ~ConnectionXillybusEntry(void);

    std::vector<ConnectionHandle> enumerate(const ConnectionHandle &hint);

    IConnection *make(const ConnectionHandle &handle);

private:
    #ifndef __unix__
    std::string DeviceName(unsigned int index);
    #else
    #endif
};

}
